@@ -121,7 +121,7 @@ hook_plot_tex = function(x, options) {
         scap = strsplit(cap, '[$:.;]')[[1L]][1L]
       }
       scap = if (is.null(scap) || is.na(scap)) '' else sprintf('[%s]', scap)
-      fig2 = sprintf('\\caption%s{%s\\label{%s}}\n\\end{%s}\n', scap, cap,
+      fig2 = sprintf('\\caption%s{%s}\\label{%s}\n\\end{%s}\n', scap, cap,
                      paste(lab, if (mcap) fig.cur, sep = ''), options$fig.env)
     }
   } else if (pandoc_to(c('latex', 'beamer'))) {
@@ -235,7 +235,7 @@ hook_plot_tex = function(x, options) {
 #' @references See output hooks in \url{http://yihui.name/knitr/hooks}.
 #'
 #'   Jekyll and Liquid:
-#'   \url{https://github.com/mojombo/jekyll/wiki/Liquid-Extensions};
+#'   \url{https://github.com/jekyll/jekyll/wiki/Liquid-Extensions};
 #'   prettify.js: \url{http://code.google.com/p/google-code-prettify/}
 render_latex = function() {
   test_latex_pkg('framed', system.file('misc', 'framed.sty', package = 'knitr'))
