@@ -63,9 +63,7 @@ render_markdown = function(strict = FALSE) {
       x = paste(c('', x), collapse = '\n')
       fence = '```'
       if (grepl('\n`{3,}', x)) {
-        print(gregexpr('\n`{3,}', x))
         l = attr(gregexpr('\n`{3,}', x)[[1]], 'match.length', exact = TRUE)
-        print(l)
         l = max(l)
         if (l >= 4) fence = paste(rep('`', l), collapse = '')
       }
@@ -76,6 +74,7 @@ render_markdown = function(strict = FALSE) {
     language = tolower(options$engine)
     if (language == 'node')
         language = 'javascript'
+    if (!options$highlight) language = 'text'
     paste('\n\n```', language, '\n', x, '```\n\n', sep = '')
   }
   knit_hooks$set(
