@@ -21,8 +21,7 @@
 #' @param caption the table caption
 #' @param escape escape special characters when producing HTML or LaTeX tables
 #' @param ... other arguments (see examples)
-#' @return A character vector of the table source code. When \code{output =
-#'   TRUE}, the results are also written into the console as a side-effect.
+#' @return A character vector of the table source code.
 #' @seealso Other R packages such as \pkg{xtable} and \pkg{tables} for HTML and
 #'   LaTeX tables, and \pkg{ascii} and \pkg{pander} for different flavors of
 #'   markdown output and some advanced features and table styles.
@@ -90,7 +89,7 @@ kable = function(
   if (any(isn)) {
     if (is.matrix(x)) {
       if (is.table(x) && length(dim(x)) == 2) class(x) = 'matrix'
-      x = format(as.data.frame(x), trim = TRUE)
+      x = format_matrix(x)
     } else x[, isn] = format(x[, isn], trim = TRUE)
   }
   if (is.na(row.names))
@@ -111,6 +110,15 @@ kable = function(
   structure(res, format = format, class = 'knitr_kable')
 }
 
+# as.data.frame() does not allow duplicate row names (#898)
+format_matrix = function(x) {
+  nms = rownames(x)
+  rownames(x) = NULL
+  x = as.matrix(format(as.data.frame(x), trim = TRUE))
+  rownames(x) = nms
+  x
+}
+
 #' @export
 print.knitr_kable = function(x, ...) {
   if (!(attr(x, 'format') %in% c('html', 'latex'))) cat('\n\n')
@@ -127,10 +135,10 @@ knit_print.knitr_kable = function(x, ...) {
 
 kable_latex = function(
   x, booktabs = FALSE, longtable = FALSE,
-  vline = if (booktabs) '' else '|',
-  toprule = if (booktabs) '\\toprule' else '\\hline',
-  bottomrule = if (booktabs) '\\bottomrule' else '\\hline',
-  midrule = if (booktabs) '\\midrule' else '\\hline',
+  vline = getOption('knitr.table.vline', if (booktabs) '' else '|'),
+  toprule = getOption('knitr.table.toprule', if (booktabs) '\\toprule' else '\\hline'),
+  bottomrule = getOption('knitr.table.bottomrule', if (booktabs) '\\bottomrule' else '\\hline'),
+  midrule = getOption('knitr.table.midrule', if (booktabs) '\\midrule' else '\\hline'),
   linesep = if (booktabs) c('', '', '', '', '\\addlinespace') else '\\hline',
   caption = NULL, table.envir = if (!is.null(caption)) 'table', escape = TRUE
 ) {
@@ -150,6 +158,8 @@ kable_latex = function(
   linesep = ifelse(linesep == "", linesep, paste('\n', linesep, sep = ''))
 
   if (escape) x = escape_latex(x)
+  if (!is.character(toprule)) toprule = NULL
+  if (!is.character(bottomrule)) bottomrule = NULL
 
   paste(c(
     env1,
@@ -213,18 +223,20 @@ kable_mark = function(x, sep.row = c('=', '=', '='), sep.col = '  ', padding = 0
   if (sep.col == '|') for (j in seq_len(ncol(x))) {
     x[, j] = gsub('\\|', '&#124;', x[, j])
   }
-  l = apply(x, 2, function(z) max(nchar(z), na.rm = TRUE))
+  l = if (prod(dim(x)) > 0) apply(x, 2, function(z) max(nchar(z), na.rm = TRUE))
   cn = colnames(x)
-  if (!is.null(cn)) {
+  if (length(cn) > 0) {
+    cn[is.na(cn)] = "NA"
     if (sep.col == '|') cn = gsub('\\|', '&#124;', cn)
     if (grepl('^\\s*$', cn[1L])) cn[1L] = rownames.name  # no empty cells for reST
-    l = pmax(l, nchar(cn))
+    l = pmax(if (length(l) == 0) 0 else l, nchar(cn))
   }
-  padding = padding * if (is.null(align <- attr(x, 'align', exact = TRUE))) 2 else {
+  align = attr(x, 'align', exact = TRUE)
+  padding = padding * if (length(align) == 0) 2 else {
     ifelse(align == 'c', 2, 1)
   }
   l = pmax(l + padding, 3)  # at least of width 3 for Github Markdown
-  s = sapply(l, function(i) paste(rep(sep.row[2], i), collapse = ''))
+  s = unlist(lapply(l, function(i) paste(rep(sep.row[2], i), collapse = '')))
   res = rbind(if (!is.na(sep.row[1])) s, cn, align.fun(s, align),
               x, if (!is.na(sep.row[3])) s)
   apply(mat_pad(res, l, align), 1, paste, collapse = sep.col)
@@ -256,11 +268,13 @@ kable_pandoc = function(x, caption = NULL, padding = 1, ...) {
 
 # pad a matrix
 mat_pad = function(m, width, align = NULL) {
-  stopifnot((n <- ncol(m)) == length(width))
+  n = ncol(m)
   res = matrix('', nrow = nrow(m), ncol = n)
+  if (prod(dim(m)) == 0) return(res)
+  stopifnot(n == length(width))
   side = rep('both', n)
   if (!is.null(align)) side = c(l = 'right', c = 'both', r = 'left')[align]
-  for (j in 1:n) {
+  for (j in seq_len(n)) {
     res[, j] = str_pad(m[, j], width[j], side = side[j])
   }
   res
