@@ -113,7 +113,8 @@ knit_expand = function(file, ..., text = readLines(file, warn = FALSE),
   delim = gsub('([.|()\\^{}+$*?]|\\[|\\])', '\\\\\\1', delim)
   delim = paste(delim[1L], '((.|\n)+?)', delim[2L], sep = '')
 
-  txt = paste(text, collapse = '\n'); delim = perl(delim)
+  txt = paste(text, collapse = '\n')
+  if (packageVersion('stringr') <= '0.9.0') delim = perl(delim)
   loc = str_locate_all(txt, delim)[[1L]]
   if (nrow(loc) == 0L) return(txt) # no match
   mat = str_extract_all(txt, delim)[[1L]]
